@@ -39,6 +39,7 @@ Package::Package()
 
 Package::~Package()
 {
+  // no code
 }
 
 void Package::SetName(const std::wstring& name)
@@ -169,66 +170,3 @@ bool Package::LoadPackageContent(std::list<std::wstring>& content)
   return true;
 }
 
-PackageEntry::PackageEntry(Package* package)
- : package(package),
-   nameObject(NULL)
-{
-}
-
-PackageEntry::~PackageEntry()
-{
-  delete nameObject;
-}
-
-Lum::Object* PackageEntry::GetObject(size_t column) const
-{
-  switch (column) {
-  case 1:
-    if (nameObject==NULL) {
-      Lum::Panel *panel;
-      Lum::Text  *text;
-
-      panel=Lum::VPanel::Create(true,true);
-
-      text=new Lum::Text();
-      text->SetFlex(true,true);
-      text->AddText(package->GetName(),Lum::OS::Font::bold);
-      text->AddText(L" (");
-      text->AddText(package->GetSection(),
-                    Lum::OS::Font::normal,
-                    Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote));
-      text->AddText(L")");
-      panel->Add(text);
-
-      text=new Lum::Text(package->GetShortDescription(),
-                         Lum::OS::Font::italic,
-                         Lum::Text::left,
-                         Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote));
-      text->SetFlex(true,true);
-      panel->Add(text);
-
-      nameObject=panel;
-    }
-    return nameObject;
-  default:
-    return NULL;
-  }
-}
-
-std::wstring PackageEntry::GetString(size_t column) const
-{
-  switch (column) {
-  case 1:
-    return L"";
-  case 2:
-    return package->GetVersion();
-  default:
-    assert(false);
-  }
-}
-
-Package* PackageEntry::GetPackage() const
-{
-  return package;
-}
-
