@@ -78,21 +78,5 @@ public:
   bool         LoadPackageContent(std::list<std::wstring>& content);
 };
 
-class PackageEntry
-{
-private:
-          Package     *package;
-  mutable Lum::Object *nameObject;
-
-public:
-  PackageEntry(Package* package);
-  virtual ~PackageEntry();
-
-  Lum::Object* GetObject(size_t column) const;
-  std::wstring GetString(size_t column) const;
-
-  Package* GetPackage() const;
-};
-
 #endif
 
