@@ -126,6 +126,7 @@ Lum::Object* PackageDetails::GetContent()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
+  edit->SetRequiresKnobs(false);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
   if (Lum::OS::display->GetSize()<Lum::OS::Display::sizeNormal) {
@@ -155,9 +156,15 @@ Lum::Object* PackageDetails::GetContent()
 
   edit=new Lum::Edit::Edit();
   edit->SetFlex(true,true);
+  edit->SetRequiresKnobs(false);
   edit->SetConfig(Lum::Edit::Config::GetDefaultConfig());
   edit->SetColorSheme(Lum::Edit::ColorSheme::GetDefaultColorSheme());
-  edit->SetFont(Lum::OS::display->GetFont());
+  if (Lum::OS::display->GetSize()<Lum::OS::Display::sizeNormal) {
+    edit->SetFont(Lum::OS::display->GetFont(70));
+  }
+  else {
+    edit->SetFont(Lum::OS::display->GetFont());
+  }
   edit->SetModel(editContent);
 
   tab->Add(L"Deps.",Lum::View::Create(edit,true,true));
